AliyunPushFlutter class
阿里云推送插件入口。
所有实例共享同一个平台实现和消息回调注册状态。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addAlias(
String alias) → Future< void> - 添加别名
-
addMessageReceiver(
{PushCallback? onNotification, PushCallback? onMessage, PushCallback? onNotificationOpened, PushCallback? onNotificationRemoved, PushCallback? onAndroidNotificationReceivedInApp, PushCallback? onAndroidNotificationClickedWithNoAction, PushCallback? onIOSChannelOpened, PushCallback? onIOSRegisterDeviceTokenSuccess, PushCallback? onIOSRegisterDeviceTokenFailed}) → void - 注册消息回调。
-
bindAccount(
String account) → Future< void> - 绑定账号
-
bindDeviceTag(
List< String> tags) → Future<void> - 绑定设备标签。
-
bindPhoneNumber(
String phone) → Future< void> - 绑定手机号码
-
bindTag(
List< String> tags, {int target = kAliyunTargetDevice, String? alias}) → Future<void> - 添加标签。
-
checkAndroidPushChannelStatus(
) → Future< AliyunPushChannelStatus> - Android 查询推送通道状态
-
clearNotifications(
) → Future< void> - 清除所有通知
-
closeAndroidPushLog(
) → Future< void> - 关闭 Android 推送日志
-
createAndroidChannel(
String id, String name, int importance, String description, {String? groupId, bool? allowBubbles, bool? light, int? lightColor, bool? showBadge, String? soundPath, int? soundUsage, int? soundContentType, int? soundFlag, bool? vibration, List< int> ? vibrationPatterns}) → Future<void> - 创建 Android 平台的NotificationChannel
-
createAndroidChannelGroup(
String id, String name, String desc) → Future< void> - 创建通知通道的分组
-
getApnsDeviceToken(
) → Future< String> - 获取APNs Token
-
getDeviceId(
) → Future< String> - 获取 deviceId
-
initAndroidThirdPush(
) → Future< void> - 注册厂商通道
-
initPush(
{String? appKey, String? appSecret}) → Future< void> - 注册推送
-
isAndroidNotificationEnabled(
{String? id}) → Future< bool> - 检查通知状态
-
isIOSChannelOpened(
) → Future< bool> - iOS 通知通道是否已打开
-
jumpToAndroidNotificationSettings(
{String? id}) → Future< void> - 跳转到通知设置页面
-
listAlias(
) → Future< List< String> > - 查询绑定别名
-
listDeviceTags(
) → Future< List< String> > - 查询当前设备绑定的标签。
-
listTags(
{int target = kAliyunTargetDevice}) → Future< List< String> > - 查询标签列表。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeAlias(
String alias) → Future< void> - 移除别名
-
setAndroidBadgeNum(
int num) → Future< void> - Android 设置角标数
-
setAndroidLogLevel(
int level) → Future< void> - 设置 Android log 的级别
-
setIOSBadgeNum(
int num) → Future< void> - 设置角标数
-
setIOSForegroundNoticeMode(
ForegroundNoticeMode mode) → Future< void> - 设置 iOS App 处于前台时的通知处理模式。
-
setIOSLogLevel(
int level) → Future< void> - 设置 iOS log 的级别
-
setNotificationInGroup(
bool inGroup) → Future< void> - 设置通知分组展示,只支持 Android
-
setPluginLogEnabled(
bool enabled) → Future< void> - 设置插件日志
-
showIOSNoticeWhenForeground(
bool enable) → Future< void> - App处于前台时是否显示通知。
-
syncIOSBadgeNum(
int num) → Future< void> - 同步角标数
-
toString(
) → String -
A string representation of this object.
inherited
-
turnOffAndroidPushChannel(
) → Future< void> - Android 关闭推送通道
-
turnOnAndroidPushChannel(
) → Future< void> - Android 开启推送通道
-
turnOnIOSDebug(
) → Future< void> - 已废弃,请改用 setIOSLogLevel(4) 开启 iOS Debug 日志。
-
unbindAccount(
) → Future< void> - 解绑账号
-
unbindDeviceTag(
List< String> tags) → Future<void> - 解绑设备标签。
-
unbindPhoneNumber(
) → Future< void> - 解绑手机号码
-
unbindTag(
List< String> tags, {int target = kAliyunTargetDevice, String? alias}) → Future<void> - 移除标签。
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited