ForegroundNoticeMode enum

iOS 前台通知处理模式。

Inheritance
Available extensions

Values

callbackOnly → const ForegroundNoticeMode

仅触发回调,不展示通知。

const ForegroundNoticeMode(0)
showOnly → const ForegroundNoticeMode

仅展示通知,不触发回调。

const ForegroundNoticeMode(1)
showAndCallback → const ForegroundNoticeMode

展示通知且触发回调。

const ForegroundNoticeMode(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
传递给 iOS 原生实现的模式值。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ForegroundNoticeMode>
A constant List of the values in this enum, in order of their declaration.